summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/tags.h
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/tags.h')
-rw-r--r--crawl-ref/source/tags.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/crawl-ref/source/tags.h b/crawl-ref/source/tags.h
index c9df422832..f07b3616b0 100644
--- a/crawl-ref/source/tags.h
+++ b/crawl-ref/source/tags.h
@@ -63,9 +63,12 @@ enum tag_minor_version
TAG_MINOR_SVNREV = 13, // Added SVN revision
TAG_MINOR_PORTEXT = 14, // Keep track of portal vault extensions.
TAG_MINOR_RELIGION = 15, // Keep track of ghosts' religions.
+ // XXX: Release 0.5 -> switch to major version 6
+ // Does that mean we can remove all the above minor version checks?
TAG_MINOR_ARTEFACT = 16, // Turned fixed arts into unrandarts.
TAG_MINOR_JIYVA = 17, // Added some player bits for Jiyva.
- TAG_MINOR_VERSION = 17 // Current version. (Keep equal to max.)
+ TAG_MINOR_ZOT_OPEN = 18, // Remember whether Zot was opened.
+ TAG_MINOR_VERSION = 18 // Current version. (Keep equal to max.)
};